=========================
 Invenio Theme v1.0.0a14
=========================

Invenio Theme v1.0.0a14 was released on August 28, 2016.

About
-----

Invenio standard theme.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-theme==1.0.0a14

Documentation
-------------

   http://pythonhosted.org/invenio-theme/

Happy hacking and thanks for flying Invenio Theme.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-theme
|   URL: http://inveniosoftware.org
